Package: MPFE
Type: Package
Title: Estimation of the amplicon methylation pattern distribution from
        bisulphite sequencing data
Version: 1.47.0
Date: 2014-11-28
Author: Peijie Lin, Sylvain Foret, Conrad Burden
biocViews: HighThroughputSequencingData, DNAMethylation, MethylSeq
Maintainer: Conrad Burden <conrad.burden@anu.edu.au>
Description: Estimate distribution of methylation patterns from a table of counts from a bisulphite sequencing experiment given a non-conversion rate and read error rate.
License: GPL (>= 3)
git_url: https://git.bioconductor.org/packages/MPFE
git_branch: devel
git_last_commit: 8e3d15d
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 22:03:43 UTC; biocbuild
